==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/hy.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "Կիրակի",
    "Monday" : "Երկուշաբթի",
    "Tuesday" : "Երեքշաբթի",
    "Wednesday" : "Չորեքշաբթի",
    "Thursday" : "Հինգշաբթի",
    "Friday" : "Ուրբաթ",
    "Saturday" : "Շաբաթ",
    "Sun." : "Կիր.",
    "Mon." : "Երկ.",
    "Tue." : "Երք.",
    "Wed." : "Չոր.",
    "Thu." : "Հնգ.",
    "Fri." : "Ուրբ.",
    "Sat." : "Շաբ.",
    "January" : "Հունվար",
    "February" : "Փետրվար",
    "March" : "Մարտ",
    "April" : "Ապրիլ",
    "May" : "Մայիս",
    "June" : "Հունիս",
    "July" : "Հուլիս",
    "August" : "Օգոստոս",
    "September" : "Սեպտեմբեր",
    "October" : "Հոկտեմբեր",
    "November" : "Նոյեմբեր",
    "December" : "Դեկտեմբեր",
    "Jan." : "Հնվ.",
    "Feb." : "Փտվ.",
    "Mar." : "Մրտ.",
    "Apr." : "Ապր.",
    "May." : "Մյս.",
    "Jun." : "Հնս.",
    "Jul." : "Հլս.",
    "Aug." : "Օգս.",
    "Sep." : "Սեպ.",
    "Oct." : "Հոկ.",
    "Nov." : "Նոյ.",
    "Dec." : "Դեկ.",
    "seconds ago" : "վրկ. առաջ",
    "No" : "Ոչ",
    "Yes" : "Այո",
    "Cancel" : "Չեղարկել",
    "Very weak password" : "Շատ թույլ գաղտնաբառ",
    "Weak password" : "Թույլ գաղտնաբառ",
    "Good password" : "Լավ գաղտնաբառ",
    "Error" : "Սխալ",
    "Share link" : "Կիսվել հղմամբ",
    "Link" : "Հղում",
    "Password" : "Գաղտնաբառ",
    "Send" : "Ուղարկել",
    "group" : "խումբ",
    "delete" : "ջնջել",
    "Share" : "Կիսվել",
    "Warning" : "Զգուշացում",
    "Delete" : "Ջնջել",
    "Rename" : "Վերանվանել",
    "Add" : "Ավելացնել",
    "Personal" : "Անձնական",
    "Username" : "Օգտանուն",
    "New password" : "Նոր գաղտնաբառ",
    "Allow editing" : "Թույլատրել խմբագրումը",
    "can edit" : "կարող է խմբագրել",
    "can share" : "կարող է տարածել",
    "change" : "փոխել",
    "Choose" : "Ընտրել",
    "Code: %s" : "Կոդ. %s",
    "Continue" : "Շարունակել",
    "create" : "ստեղծել",
    "Data folder" : "Տվյալների պանակ",
    "Email link to person" : "Ուղարկել հղումը ոմնին",
    "Error while sharing" : "Սխալ տարածելիս",
    "File not found" : "Ֆայլը չգտնվեց",
    "File: %s" : "Ֆայլ. %s",
    "Fr" : "Ուրբ",
    "Help" : "Օգնություն",
    "invisible" : "անտեսանելի",
    "Line: %s" : "Տող. %s",
    "Log in" : "Մուտք գործել",
    "Log out" : "Դուրս գալ",
    "Message: %s" : "Նամակ. %s",
    "Mo" : "Երկ",
    "new" : "նոր",
    "New Files" : "Նոր ֆայլեր",
    "New Password" : "Նոր գաղտնաբառ",
    "Ok" : "Լավ",
    "remote" : "հեռակա",
    "Sa" : "Շաբ",
    "Search" : "Փնտրել",
    "Security warning" : "Անվտանգության զգուշացում",
    "Shared" : "Տարածած",
    "So-so password" : "Միջինոտ գաղտնաբառ",
    "Strong password" : "Ուժեղ գաղտնաբառ",
    "Su" : "Կիր",
    "sunny" : "արևոտ",
    "Th" : "Հնգ",
    "Trace" : "Հետք",
    "Tu" : "Երք",
    "Type: %s" : "Տիպ. %s",
    "We" : "Չոր"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/hy.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "Կիրակի",
    "Monday" : "Երկուշաբթի",
    "Tuesday" : "Երեքշաբթի",
    "Wednesday" : "Չորեքշաբթի",
    "Thursday" : "Հինգշաբթի",
    "Friday" : "Ուրբաթ",
    "Saturday" : "Շաբաթ",
    "Sun." : "Կիր.",
    "Mon." : "Երկ.",
    "Tue." : "Երք.",
    "Wed." : "Չոր.",
    "Thu." : "Հնգ.",
    "Fri." : "Ուրբ.",
    "Sat." : "Շաբ.",
    "Su" : "Կիր",
    "Mo" : "Երկ",
    "Tu" : "Երք",
    "We" : "Չոր",
    "Th" : "Հնգ",
    "Fr" : "Ուրբ",
    "Sa" : "Շաբ",
    "January" : "Հունվար",
    "February" : "Փետրվար",
    "March" : "Մարտ",
    "April" : "Ապրիլ",
    "May" : "Մայիս",
    "June" : "Հունիս",
    "July" : "Հուլիս",
    "August" : "Օգոստոս",
    "September" : "Սեպտեմբեր",
    "October" : "Հոկտեմբեր",
    "November" : "Նոյեմբեր",
    "December" : "Դեկտեմբեր",
    "Jan." : "Հնվ.",
    "Feb." : "Փտվ.",
    "Mar." : "Մրտ.",
    "Apr." : "Ապր.",
    "May." : "Մյս.",
    "Jun." : "Հնս.",
    "Jul." : "Հլս.",
    "Aug." : "Օգս.",
    "Sep." : "Սեպ.",
    "Oct." : "Հոկ.",
    "Nov." : "Նոյ.",
    "Dec." : "Դեկ.",
    "seconds ago" : "վրկ. առաջ",
    "No" : "Ոչ",
    "Yes" : "Այո",
    "Choose" : "Ընտրել",
    "Ok" : "Լավ",
    "New Files" : "Նոր ֆայլեր",
    "Cancel" : "Չեղարկել",
    "Continue" : "Շարունակել",
    "Very weak password" : "Շատ թույլ գաղտնաբառ",
    "Weak password" : "Թույլ գաղտնաբառ",
    "So-so password" : "Միջինոտ գաղտնաբառ",
    "Good password" : "Լավ գաղտնաբառ",
    "Strong password" : "Ուժեղ գաղտնաբառ",
    "Shared" : "Տարածած",
    "Shared with {recipients}" : "Տարածած {recipients}ի հետ",
    "Error" : "Սխալ",
    "Error while sharing" : "Սխալ տարածելիս",
    "Share link" : "Կիսվել հղմամբ",
    "Link" : "Հղում",
    "Password" : "Գաղտնաբառ",
    "Allow editing" : "Թույլատրել խմբագրումը",
    "Email link to person" : "Ուղարկել հղումը ոմնին",
    "Send" : "Ուղարկել",
    "group" : "խումբ",
    "remote" : "հեռակա",
    "can share" : "կարող է տարածել",
    "can edit" : "կարող է խմբագրել",
    "create" : "ստեղծել",
    "change" : "փոխել",
    "delete" : "ջնջել",
    "Share" : "Կիսվել",
    "Warning" : "Զգուշացում",
    "invisible" : "անտեսանելի",
    "Delete" : "Ջնջել",
    "Rename" : "Վերանվանել",
    "Add" : "Ավելացնել",
    "Hello world!" : "Բա՛րև աշխարհ։",
    "sunny" : "արևոտ",
    "Hello {name}, the weather is {weather}" : "Բարև {name}, եղանակը {weather} է",
    "Hello {name}" : "Բարև {name}",
    "new" : "նոր",
    "_download %n file_::_download %n files_" : ["ներբեռնել %n ֆայլ","ներբեռնել %n ֆայլ"],
    "Personal" : "Անձնական",
    "Help" : "Օգնություն",
    "File not found" : "Ֆայլը չգտնվեց",
    "Type: %s" : "Տիպ. %s",
    "Code: %s" : "Կոդ. %s",
    "Message: %s" : "Նամակ. %s",
    "File: %s" : "Ֆայլ. %s",
    "Line: %s" : "Տող. %s",
    "Trace" : "Հետք",
    "Security warning" : "Անվտանգության զգուշացում",
    "Username" : "Օգտանուն",
    "Data folder" : "Տվյալների պանակ",
    "Only %s is available." : "Միայն %sն է հասանելի։",
    "Log out" : "Դուրս գալ",
    "Search" : "Փնտրել",
    "Log in" : "Մուտք գործել",
    "Wrong password." : "Սխալ գաղտնաբառ։",
    "New password" : "Նոր գաղտնաբառ",
    "New Password" : "Նոր գաղտնաբառ"
},
"nplurals=2; plural=(n != 1);");
